@@ -1,330 +1,388 @@
 ##' Checks if an undirected graph is bipartite and finds the bipartite
 ##' partitions.
-##' See 'https://lemon.cs.elte.hu/pub/doc/1.3.1/a00616.html#ga58ba1d00c569f0eb0deb42afca9f80bb'
-##' for more information.
 ##'
-##' @title GetBipartitePartitions
+##' See
+##' \url{https://lemon.cs.elte.hu/pub/doc/1.3.1/a00616.html#ga58ba1d00c569f0eb0deb42afca9f80bb}
+##' for more information.
+##' @title Obtains (if possible) Bipartite Split
 ##' @param arcSources Vector corresponding to the source nodes of a graph's
 ##'   edges
 ##' @param arcTargets Vector corresponding to the destination nodes of a graph's
 ##'   edges
 ##' @param numNodes The number of nodes in the graph
-##' @return A list containing 1) A boolean stating if the graph is bipartite,
-##'   and 2) A list of length numNodes, containing the partition for each node
+##' @return A list containing 1) A \code{logical} stating if the graph is
+##'   bipartite, and 2) A vector of length \code{numNodes}, containing the
+##'   partition for each node
 ##' @export
 GetBipartitePartitions <- function(arcSources,
                                    arcTargets,
                                    numNodes) {
+
   check_graph_vertices(arcSources, arcTargets, numNodes)
-  .Call(
-    `_rlemon_getBipartitePartitionsRunner`, arcSources, arcTargets,
-    numNodes
-  )
+
+  getBipartitePartitionsRunner(arcSources, arcTargets, numNodes)
 }
 
 ##' Checks if a directed graph is a DAG and returns the topological order.
-##' See 'https://lemon.cs.elte.hu/pub/doc/1.3.1/a00616.html#gafc2cb20cf3859f157c0e12da7f310bb3'
-##' for more information.
 ##'
-##' @title GetAndCheckTopologicalSort
+##' See
+##' \url{https://lemon.cs.elte.hu/pub/doc/1.3.1/a00616.html#gaf10c5e1630e5720c20d83cfb77dbf024}
+##' for more information.
+##' @title Check if Graph is DAG, then Sorts Nodes into Topological Order
 ##' @param arcSources Vector corresponding to the source nodes of a graph's
 ##'   edges
 ##' @param arcTargets Vector corresponding to the destination nodes of a graph's
 ##'   edges
 ##' @param numNodes The number of nodes in the graph
-##' @return A list containing 1) A boolean stating if the graph is a dag, and 2)
-##'   A vector of length numNodes, containing the index of vertex i in the
-##'   ordering at location i
+##' @return A list containing 1) A \code{logical} stating if the graph is a dag,
+##'   and 2) A vector of length \code{numNodes}, containing the index of vertex
+##'   i in the ordering at location i
 ##' @export
 GetAndCheckTopologicalSort <- function(arcSources,
                                        arcTargets,
                                        numNodes) {
+
   check_graph_vertices(arcSources, arcTargets, numNodes)
-  .Call(
-    `_rlemon_getAndCheckTopologicalSortRunner`, arcSources, arcTargets,
-    numNodes
-  )
+
+  getAndCheckTopologicalSortRunner(arcSources, arcTargets, numNodes)
 }
 
 ##' Gives back the topological order of a DAG.
-##' See 'https://lemon.cs.elte.hu/pub/doc/1.3.1/a00616.html#gafc2cb20cf3859f157c0e12da7f310bb3'
-##' for more information.
 ##'
-##' @title GetTopologicalSort
+##' See
+##' \url{https://lemon.cs.elte.hu/pub/doc/1.3.1/a00616.html#gafc2cb20cf3859f157c0e12da7f310bb3}
+##' for more information.
+##' @title Sorts Nodes into Topological Order
 ##' @param arcSources Vector corresponding to the source nodes of a graph's
 ##'   edges
 ##' @param arcTargets Vector corresponding to the destination nodes of a graph's
 ##'   edges
 ##' @param numNodes The number of nodes in the graph
-##' @return A list of length numNodes, containing the index of vertex i in the
-##'   ordering at location i.
+##' @return A vector of length \code{numNodes}, containing the index of vertex i
+##'   in the ordering at location i.
 ##' @export
 GetTopologicalSort <- function(arcSources,
                                arcTargets,
                                numNodes) {
+
   check_graph_vertices(arcSources, arcTargets, numNodes)
-  .Call(`_rlemon_getTopologicalSortRunner`, arcSources, arcTargets, numNodes)
+
+  getTopologicalSortRunner(arcSources, arcTargets, numNodes)
 }
 
-##' Checks if an undirected graph is connected.
-##' See 'https://lemon.cs.elte.hu/pub/doc/1.3.1/a00616.html#gad5c8d1b650f6b614a852f8430d90e184'
-##' for more information.
+##' A connected graph has a path between any two nodes in the graph.
 ##'
-##' @title IsConnected
+##' See \url{https://lemon.cs.elte.hu/pub/doc/1.3.1/a00616.html#gad5c8d1b650f6b614a852f8430d90e184}
+##' for more information.
+##' @title Check if Graph is Connected
 ##' @param arcSources Vector corresponding to the source nodes of a graph's
 ##'   edges
 ##' @param arcTargets Vector corresponding to the destination nodes of a graph's
 ##'   edges
 ##' @param numNodes The number of nodes in the graph
-##' @return A boolean stating if the graph is connected
+##' @return A \code{logical} stating if the graph is connected
 ##' @export
 IsConnected <- function(arcSources,
                         arcTargets,
                         numNodes) {
+
   check_graph_vertices(arcSources, arcTargets, numNodes)
-  .Call(`_rlemon_IsConnectedRunner`, arcSources, arcTargets, numNodes)
+
+  as.logical(IsConnectedRunner(arcSources, arcTargets, numNodes))
 }
 
-##' Checks if an undirected graph is acyclic.
-##' See 'https://lemon.cs.elte.hu/pub/doc/1.3.1/a00616.html#ga14c191b2133a1dd23e1527f074c821c0'
-##' for more information.
+##' A cycle is a path starting and ending in the same node and containing at
+##' least one other node. A acyclic graph contains no cycles.
 ##'
-##' @title IsAcylic
+##' See \url{https://lemon.cs.elte.hu/pub/doc/1.3.1/a00616.html#ga14c191b2133a1dd23e1527f074c821c0}
+##' for more information.
+##' @title Check if Graph is Acyclic.
 ##' @param arcSources Vector corresponding to the source nodes of a graph's
 ##'   edges
 ##' @param arcTargets Vector corresponding to the destination nodes of a graph's
 ##'   edges
 ##' @param numNodes The number of nodes in the graph
-##' @return A boolean stating if the graph is acyclic
+##' @return A \code{logical} stating if the graph is acyclic
 ##' @export
 IsAcyclic <- function(arcSources,
                       arcTargets,
                       numNodes) {
+
   check_graph_vertices(arcSources, arcTargets, numNodes)
-  .Call(`_rlemon_IsAcyclicRunner`, arcSources, arcTargets, numNodes)
+
+  as.logical(IsAcyclicRunner(arcSources, arcTargets, numNodes))
 }
 
-##' Checks if an undirected graph is a tree.
-##' See 'https://lemon.cs.elte.hu/pub/doc/1.3.1/a00616.html#gad1e4de234e926958647905478415bd54'
-##' for more information.
+##' A tree is an undirected graph in which any two nodes are connected by
+##' exactly one path, or equivalently is both connected and acyclic.
 ##'
-##' @title IsTree
+##' See \url{https://lemon.cs.elte.hu/pub/doc/1.3.1/a00616.html#gad1e4de234e926958647905478415bd54}
+##' for more information.
+##' @title Check if Graph is a Tree
 ##' @param arcSources Vector corresponding to the source nodes of a graph's
 ##'   edges
 ##' @param arcTargets Vector corresponding to the destination nodes of a graph's
 ##'   edges
 ##' @param numNodes The number of nodes in the graph
-##' @return A boolean stating if the graph is a tree
+##' @return A \code{logical} stating if the graph is a tree
 ##' @export
 IsTree <- function(arcSources,
                    arcTargets,
                    numNodes) {
+
   check_graph_vertices(arcSources, arcTargets, numNodes)
-  .Call(`_rlemon_IsTreeRunner`, arcSources, arcTargets, numNodes)
+
+  as.logical(IsTreeRunner(arcSources, arcTargets, numNodes))
 }
 
-##' Checks if an undirected graph is bipartite.
-##' See 'https://lemon.cs.elte.hu/pub/doc/1.3.1/a00616.html#ga577db110d33bd487aaad5bfffb31c6f5'
-##' for more information.
+##' A bipartite graph is one whose nodes can be divided into two disjoint and
+##' independent sets such that edges only connecte between those two sets and
+##' not within a set.
 ##'
-##' @title IsBipartite
+##' See \url{https://lemon.cs.elte.hu/pub/doc/1.3.1/a00616.html#ga577db110d33bd487aaad5bfffb31c6f5}
+##' for more information.
+##' @title Checks if Graph is Bipartite
 ##' @param arcSources Vector corresponding to the source nodes of a graph's
 ##'   edges
 ##' @param arcTargets Vector corresponding to the destination nodes of a graph's
 ##'   edges
 ##' @param numNodes The number of nodes in the graph
-##' @return A boolean stating if the graph is bipartite
+##' @return A \code{logical} stating if the graph is bipartite
 ##' @export
 IsBipartite <- function(arcSources,
                         arcTargets,
                         numNodes) {
+
   check_graph_vertices(arcSources, arcTargets, numNodes)
-  .Call(`_rlemon_IsBipartiteRunner`, arcSources, arcTargets, numNodes)
+
+  as.logical(IsBipartiteRunner(arcSources, arcTargets, numNodes))
 }
 
-##' Checks if a directed graph is strongly connected.
-##' See 'https://lemon.cs.elte.hu/pub/doc/1.3.1/a00616.html#gacd21b34d7b42b9835a204a57fcf15964'
-##' for more information.
+##' A directed graph is strongly connected if any two nodes are connected via
+##' paths in both directions.
 ##'
-##' @title IsStronglyConnected
+##' See \url{https://lemon.cs.elte.hu/pub/doc/1.3.1/a00616.html#gacd21b34d7b42b9835a204a57fcf15964}
+##' for more information.
+##' @title Check if Graph is Strongly Connected
 ##' @param arcSources Vector corresponding to the source nodes of a graph's
 ##'   edges
 ##' @param arcTargets Vector corresponding to the destination nodes of a graph's
 ##'   edges
 ##' @param numNodes The number of nodes in the graph
-##' @return A boolean stating if the graph is strongly connected
+##' @return A \code{logical} stating if the graph is strongly connected
 ##' @export
 IsStronglyConnected <- function(arcSources,
                                 arcTargets,
                                 numNodes) {
+
   check_graph_vertices(arcSources, arcTargets, numNodes)
-  .Call(`_rlemon_IsStronglyConnectedRunner`, arcSources, arcTargets, numNodes)
+
+  as.logical(IsStronglyConnectedRunner(arcSources, arcTargets, numNodes))
 }
 
-##' Checks if a directed graph is a DAG.
-##' See 'https://lemon.cs.elte.hu/pub/doc/1.3.1/a00616.html#gaef2b43c8cd1d74e15fa5c7607bc5e396'
-##' for more information.
+##' A graph is a DAG if it is Directed and Acyclic.
 ##'
-##' @title IsDAG
+##' See \url{https://lemon.cs.elte.hu/pub/doc/1.3.1/a00616.html#gaef2b43c8cd1d74e15fa5c7607bc5e396}
+##' for more information.
+##' @title Check if Graph is a DAG.
 ##' @param arcSources Vector corresponding to the source nodes of a graph's
 ##'   edges
 ##' @param arcTargets Vector corresponding to the destination nodes of a graph's
 ##'   edges
 ##' @param numNodes The number of nodes in the graph
-##' @return A boolean stating if the graph is DAG
+##' @return A \code{logical} stating if the graph is DAG
 ##' @export
 IsDAG <- function(arcSources,
                   arcTargets,
                   numNodes) {
   check_graph_vertices(arcSources, arcTargets, numNodes)
-  .Call(`_rlemon_IsDAGRunner`, arcSources, arcTargets, numNodes)
+  as.logical(IsDAGRunner(arcSources, arcTargets, numNodes))
 }
 
-##' Checks if an undirected graph is bi-node connected.
-##' See 'https://lemon.cs.elte.hu/pub/doc/1.3.1/a00616.html#ga37d22a2ddd5a064a9203720f2b93518e'
-##' for more information.
+##' Checks if an undirected graph is bi-node-connected, that is if there is are no
+##' nodes which, if removed, would split the graph into two unconnected graphs.
 ##'
-##' @title IsBiNodeConnected
+##' See \url{https://lemon.cs.elte.hu/pub/doc/1.3.1/a00616.html#gac9257323ead7cbe64b7b4a628c4876b3}
+##' for more information.
+##' @title Checks if Graph is Bi-Node-Connected
 ##' @param arcSources Vector corresponding to the source nodes of a graph's
 ##'   edges
 ##' @param arcTargets Vector corresponding to the destination nodes of a graph's
 ##'   edges
 ##' @param numNodes The number of nodes in the graph
-##' @return A boolean stating if the graph is bi-node connected
+##' @return A \code{logical} stating if the graph is bi-node connected
 ##' @export
 IsBiNodeConnected <- function(arcSources,
                               arcTargets,
                               numNodes) {
+
   check_graph_vertices(arcSources, arcTargets, numNodes)
-  .Call(`_rlemon_IsBiNodeConnectedRunner`, arcSources, arcTargets, numNodes)
+
+  as.logical(IsBiNodeConnectedRunner(arcSources, arcTargets, numNodes))
 }
 
-##' Checks if an undirected graph is bi-edge connected.
-##' See 'https://lemon.cs.elte.hu/pub/doc/1.3.1/a00616.html#ga37d22a2ddd5a064a9203720f2b93518e'
-##' for more information.
+##' Checks if an undirected graph is bi-edge-connected, that is if there are no
+##' edges that, if removed, would split the graph into two unconnected graphs.
 ##'
-##' @title IsBiEdgeConnected
+##' See
+##' \url{https://lemon.cs.elte.hu/pub/doc/1.3.1/a00616.html#ga37d22a2ddd5a064a9203720f2b93518e}
+##' for more information.
+##' @title Chcek if Graph is Bi-Edge-Connected
 ##' @param arcSources Vector corresponding to the source nodes of a graph's
 ##'   edges
 ##' @param arcTargets Vector corresponding to the destination nodes of a graph's
 ##'   edges
 ##' @param numNodes The number of nodes in the graph
-##' @return A boolean stating if the graph is bi-edge connected
+##' @return A \code{logical} stating if the graph is bi-edge connected
 ##' @export
 IsBiEdgeConnected <- function(arcSources,
                               arcTargets,
                               numNodes) {
+
   check_graph_vertices(arcSources, arcTargets, numNodes)
-  .Call(`_rlemon_IsBiEdgeConnectedRunner`, arcSources, arcTargets, numNodes)
+
+  as.logical(IsBiEdgeConnectedRunner(arcSources, arcTargets, numNodes))
 }
 
-##' Checks if a graph is loop free. Works for both undirected and directed
-##' graphs.
-##' See 'https://lemon.cs.elte.hu/pub/doc/1.3.1/a00616.html#ga127f3963003cd532c79c226885fe1c8c'
-##' for more information.
+##' A loop is an edge that starts and ends at the same node and passes through
+##' no other nodes.
 ##'
-##' @title IsLoopFree
+##' See \url{https://lemon.cs.elte.hu/pub/doc/1.3.1/a00616.html#ga127f3963003cd532c79c226885fe1c8c}
+##' for more information.
+##' @title Checks if Graph is Loop Free
 ##' @param arcSources Vector corresponding to the source nodes of a graph's
 ##'   edges
 ##' @param arcTargets Vector corresponding to the destination nodes of a graph's
 ##'   edges
 ##' @param numNodes The number of nodes in the graph
-##' @return A boolean stating if the graph is loop free
+##' @return TRUE if the graph is loop free, FALSE otherwise
 ##' @export
 IsLoopFree <- function(arcSources,
                        arcTargets,
                        numNodes) {
+
   check_graph_vertices(arcSources, arcTargets, numNodes)
-  .Call(`_rlemon_IsLoopFreeRunner`, arcSources, arcTargets, numNodes)
+
+  as.logical(IsLoopFreeRunner(arcSources, arcTargets, numNodes))
 }
 
-##' Checks if a graph has no parallel arcs/edges. Works for both undirected and
-##' directed graphs.
-##' See 'https://lemon.cs.elte.hu/pub/doc/1.3.1/a00616.html#gaa05e0683f90b69f31eb29fe7d09afde4'
-##' for more information.
+##' Parallel edges occur when there are two edges between a single pair of nodes.
 ##'
-##' @title IsParallelFree
+##' See
+##' \url{https://lemon.cs.elte.hu/pub/doc/1.3.1/a00616.html#gaa05e0683f90b69f31eb29fe7d09afde4}
+##' for more information.
+##' @title Check if Graph is Parallel Free
 ##' @param arcSources Vector corresponding to the source nodes of a graph's
 ##'   edges
 ##' @param arcTargets Vector corresponding to the destination nodes of a graph's
 ##'   edges
 ##' @param numNodes The number of nodes in the graph
-##' @return A boolean stating if the graph is loop free
+##' @return TRUE if the graph is parallel free, FALSE otherwise
 ##' @export
 IsParallelFree <- function(arcSources,
                            arcTargets,
                            numNodes) {
+
   check_graph_vertices(arcSources, arcTargets, numNodes)
-  .Call(`_rlemon_IsParallelFreeRunner`, arcSources, arcTargets, numNodes)
+
+  as.logical(IsParallelFreeRunner(arcSources, arcTargets, numNodes))
 }
 
-##' Checks if a graph is simple, i.e. it contains no loop arcs/edges and no
-##' parallel arcs/edges. Works for both undirected and directed graphs.
-##' See 'https://lemon.cs.elte.hu/pub/doc/1.3.1/a00616.html#gae4c7ae734e2509ab78dc747d602c9236'
-##' for more information.
+##' A graph is simple if it is both loop free, and parallel free. See also
+##' \code{IsLoopFree} and \code{IsParallelFree}.
 ##'
-##' @title IsSimpleGraph
+##' See \url{https://lemon.cs.elte.hu/pub/doc/1.3.1/a00616.html#gae4c7ae734e2509ab78dc747d602c9236}
+##' for more information.
+##' @title Check if Graph is Simple
 ##' @param arcSources Vector corresponding to the source nodes of a graph's
 ##'   edges
 ##' @param arcTargets Vector corresponding to the destination nodes of a graph's
 ##'   edges
 ##' @param numNodes The number of nodes in the graph
-##' @return A boolean stating if the graph is simple
+##' @return TRUE if graph is simple, FALSE otherwise.
 ##' @export
 IsSimpleGraph <- function(arcSources,
                           arcTargets,
                           numNodes) {
+
   check_graph_vertices(arcSources, arcTargets, numNodes)
-  .Call(`_rlemon_IsSimpleGraphRunner`, arcSources, arcTargets, numNodes)
+
+  as.logical(IsSimpleGraphRunner(arcSources, arcTargets, numNodes))
 }
 
-##' Checks if a graph is Eulerian. Works for both undirected and directed
-##' graphs.
-##' See 'https://lemon.cs.elte.hu/pub/doc/1.3.1/a00616.html#gafb5a4961cac4d877006869fc4cb6ea1d'
-##' for more information.
+##' A directed graph is Eulerian if and only if it is connected and the number
+##' of incoming and outgoing edges are the same for each node. An undirected
+##' graph is Eulerian if and only if it is connected and the number of incident
+##' edges is even for each node.
 ##'
-##' @title IsEulerian
+##' See \url{https://lemon.cs.elte.hu/pub/doc/1.3.1/a00616.html#gafb5a4961cac4d877006869fc4cb6ea1d}
+##' for more information.
+##' @title Check if Graph is Eulerian
 ##' @param arcSources Vector corresponding to the source nodes of a graph's
 ##'   edges
 ##' @param arcTargets Vector corresponding to the destination nodes of a graph's
 ##'   edges
 ##' @param numNodes The number of nodes in the graph
-##' @return A boolean stating if the graph is Eulerian
+##' @return TRUE if graph is Eulerian, FALSE otherwise
 ##' @export
 IsEulerian <- function(arcSources,
                        arcTargets,
                        numNodes) {
+
   check_graph_vertices(arcSources, arcTargets, numNodes)
-  .Call(`_rlemon_IsEulerianRunner`, arcSources, arcTargets, numNodes)
+
+  as.logical(IsEulerianRunner(arcSources, arcTargets, numNodes))
 }
 
-##' Counts the number of bi-edge connected components in an undirected graph.
-##' See 'https://lemon.cs.elte.hu/pub/doc/1.3.1/a00616.html#gaf7c5744b2175210b8ea67897aaa27885'
-##' for more information.
+##' Counts the number of bi-edge-connected components in an undirected graph.
 ##'
-##' @title CountBiEdgeConnectedComponents
+##' See \url{https://lemon.cs.elte.hu/pub/doc/1.3.1/a00616.html#ga4d5db78dc21099d075c3967484990954}
+##' for more information.
+##' @title Count Number of Bi-Edge-Connected Components
 ##' @param arcSources Vector corresponding to the source nodes of a graph's
 ##'   edges
 ##' @param arcTargets Vector corresponding to the destination nodes of a graph's
 ##'   edges
 ##' @param numNodes The number of nodes in the graph
-##' @return An integer defining the number of bi-node connected components
+##' @return An integer defining the number of bi-edge-connected components
 ##' @export
 CountBiEdgeConnectedComponents <- function(arcSources,
                                            arcTargets,
                                            numNodes) {
+
   check_graph_vertices(arcSources, arcTargets, numNodes)
-  .Call(
-    `_rlemon_CountBiEdgeConnectedComponentsRunner`, arcSources, arcTargets,
-    numNodes
-  )
+
+  CountBiEdgeConnectedComponentsRunner(arcSources, arcTargets, numNodes )
 }
 
-##' Counts the number of connected components in an undirected graph.
-##' See 'https://lemon.cs.elte.hu/pub/doc/1.3.1/a00616.html#ga33a9d9d4803cb15e83568b2526e978a5'
-##' for more information.
+##' Counts the number of bi-node-connected components in an undirected graph.
 ##'
-##' @title CountConnectedComponents
+##' See \url{https://lemon.cs.elte.hu/pub/doc/1.3.1/a00616.html#gaf7c5744b2175210b8ea67897aaa27885}
+##' for more information.
+##' @title Count Number of Bi-Node-Connected Components
+##' @param arcSources Vector corresponding to the source nodes of a graph's
+##'   edges
+##' @param arcTargets Vector corresponding to the destination nodes of a graph's
+##'   edges
+##' @param numNodes The number of nodes in the graph
+##' @return An integer defining the number of bi-node-connected components
+##' @export
+CountBiNodeConnectedComponents <- function(arcSources,
+                                           arcTargets,
+                                           numNodes) {
+
+  check_graph_vertices(arcSources, arcTargets, numNodes)
+
+  CountBiNodeConnectedComponentsRunner(arcSources, arcTargets, numNodes)
+}
+
+##' The connected components are the classes of an equivalence relation on the
+##' nodes of an undirected graph. Two nodes are in the same class if they are
+##' connected with a path.
+##'
+##' See \url{https://lemon.cs.elte.hu/pub/doc/1.3.1/a00616.html#ga33a9d9d4803cb15e83568b2526e978a5}
+##' for more information.
+##' @title Count the Number of Connected Components
 ##' @param arcSources Vector corresponding to the source nodes of a graph's
 ##'   edges
 ##' @param arcTargets Vector corresponding to the destination nodes of a graph's
@@ -335,40 +393,20 @@ CountBiEdgeConnectedComponents <- function(arcSources,
 CountConnectedComponents <- function(arcSources,
                                      arcTargets,
                                      numNodes) {
+
   check_graph_vertices(arcSources, arcTargets, numNodes)
-  .Call(
-    `_rlemon_CountConnectedComponentsRunner`, arcSources, arcTargets,
-    numNodes
-  )
+
+  CountConnectedComponentsRunner(arcSources, arcTargets, numNodes)
 }
 
-##' Counts the number of bi-node connected components in an undirected graph.
-##' See 'https://lemon.cs.elte.hu/pub/doc/1.3.1/a00616.html#gaf7c5744b2175210b8ea67897aaa27885'
-##' for more information.
-##'
-##' @title CountBiNodeConnectedComponents
-##' @param arcSources Vector corresponding to the source nodes of a graph's
-##'   edges
-##' @param arcTargets Vector corresponding to the destination nodes of a graph's
-##'   edges
-##' @param numNodes The number of nodes in the graph
-##' @return An integer defining the number of bi-node connected components
-##' @export
-CountBiNodeConnectedComponents <- function(arcSources,
-                                           arcTargets,
-                                           numNodes) {
-  check_graph_vertices(arcSources, arcTargets, numNodes)
-  .Call(
-    `_rlemon_CountBiNodeConnectedComponentsRunner`, arcSources, arcTargets,
-    numNodes
-  )
-}
 
-##' Counts the number of strongly connected components in a directed graph.
-##' See 'https://lemon.cs.elte.hu/pub/doc/1.3.1/a00616.html#gad30bc47dfffb78234eeee903cb3766f4'
-##' for more information.
+##' The strongly connected components are the classes of an equivalence relation
+##' on the nodes of a directed graph. Two nodes are in the same class if they
+##' are connected with directed paths in both direction.
 ##'
-##' @title CountStronglyConnectedComponents
+##' See \url{https://lemon.cs.elte.hu/pub/doc/1.3.1/a00616.html#gad30bc47dfffb78234eeee903cb3766f4}
+##' for more information.
+##' @title Count the Number of Strongly Connected Components
 ##' @param arcSources Vector corresponding to the source nodes of a graph's
 ##'   edges
 ##' @param arcTargets Vector corresponding to the destination nodes of a graph's
@@ -379,165 +417,175 @@ CountBiNodeConnectedComponents <- function(arcSources,
 CountStronglyConnectedComponents <- function(arcSources,
                                              arcTargets,
                                              numNodes) {
+
   check_graph_vertices(arcSources, arcTargets, numNodes)
-  .Call(
-    `_rlemon_CountStronglyConnectedComponentsRunner`, arcSources,
-    arcTargets, numNodes
-  )
+
+  CountStronglyConnectedComponentsRunner(arcSources, arcTargets, numNodes)
 }
 
-##' Finds the strongly connected components in a directed graph.
-##' See 'https://lemon.cs.elte.hu/pub/doc/1.3.1/a00616.html#ga46f8c22f3e2989c4689faa4c46ec9436'
-##' for more information.
+##' The strongly connected components are the classes of an equivalence relation
+##' on the nodes of a directed graph. Two nodes are in the same class if they
+##' are connected with directed paths in both direction.
 ##'
-##' @title FindStronglyConnectedComponents
+##' See \url{https://lemon.cs.elte.hu/pub/doc/1.3.1/a00616.html#ga46f8c22f3e2989c4689faa4c46ec9436}
+##' for more information.
+##' @title Find Strongly Connected Components
 ##' @param arcSources Vector corresponding to the source nodes of a graph's
 ##'   edges
 ##' @param arcTargets Vector corresponding to the destination nodes of a graph's
 ##'   edges
 ##' @param numNodes The number of nodes in the graph
-##' @return A list containing the node id of each strongly connected component.
+##' @return A vector containing the node id of each strongly connected component.
 ##' @export
 FindStronglyConnectedComponents <- function(arcSources,
                                             arcTargets,
                                             numNodes) {
+
   check_graph_vertices(arcSources, arcTargets, numNodes)
-  .Call(
-    `_rlemon_FindStronglyConnectedComponentsRunner`, arcSources, arcTargets,
-    numNodes
-  )
+
+  FindStronglyConnectedComponentsRunner(arcSources, arcTargets, numNodes)
 }
 
-##' Finds the cut arcs of strongly connected components in a directed graph.
-##' See 'https://lemon.cs.elte.hu/pub/doc/1.3.1/a00616.html#gad7af5c3a97453e37f251f0e86dbb83db'
-##' for more information.
+##' The strongly connected components are the classes of an equivalence relation
+##' on the nodes of a directed graph. Two nodes are in the same class if they
+##' are connected with directed paths in both direction. The strongly connected
+##' components are separated by the cut arcs.
 ##'
-##' @title FindStronglyConnectedCutArcs
+##' See
+##' \url{https://lemon.cs.elte.hu/pub/doc/1.3.1/a00616.html#gad7af5c3a97453e37f251f0e86dbb83db}
+##' for more information.
+##' @title Find Strongly Connected Cut Arcs
 ##' @param arcSources Vector corresponding to the source nodes of a graph's
 ##'   edges
 ##' @param arcTargets Vector corresponding to the destination nodes of a graph's
 ##'   edges
 ##' @param numNodes The number of nodes in the graph
-##' @return A list containing 1) A list of cut arc sources, and 2) A list of cut
-##'   arc destinations.
+##' @return A list containing 1) A vector of cut arc sources, and 2) A vector of
+##'   cut arc destinations.
 ##' @export
 FindStronglyConnectedCutArcs <- function(arcSources,
                                          arcTargets,
                                          numNodes) {
+
   check_graph_vertices(arcSources, arcTargets, numNodes)
-  .Call(
-    `_rlemon_FindStronglyConnectedCutArcsRunner`, arcSources, arcTargets,
-    numNodes
-  )
+
+  FindStronglyConnectedCutArcsRunner(arcSources, arcTargets, numNodes)
 }
 
-##' Finds the bi-edge-connected cut edges in an undirected graph.
-##' See 'https://lemon.cs.elte.hu/pub/doc/1.3.1/a00616.html#ga58d444eba448c5f1a53539bd1b69636e'
-##' for more information.
+##' The bi-edge-connected components are the classes of an equivalence relation
+##' on the nodes of an undirected graph. Two nodes are in the same class if they
+##' are connected with at least two edge-disjoint paths. The bi-edge-connected
+##' components are separted by the cut edges of the components.
 ##'
-##' @title FindBiEdgeConnectedCutEdges
+##' See
+##' \url{https://lemon.cs.elte.hu/pub/doc/1.3.1/a00616.html#ga58d444eba448c5f1a53539bd1b69636e}
+##' for more information.
+##' @title Find Bi-Edge-Connected Cut Edges
 ##' @param arcSources Vector corresponding to the source nodes of a graph's
 ##'   edges
 ##' @param arcTargets Vector corresponding to the destination nodes of a graph's
 ##'   edges
 ##' @param numNodes The number of nodes in the graph
-##' @return A list containing 1) A list of cut arc sources, and 2) A list of cut
-##'   arc destinations.
+##' @return A list containing 1) A vector of cut edge sources, and 2) A vector
+##'   of cut edge destinations.
 ##' @export
 FindBiEdgeConnectedCutEdges <- function(arcSources,
                                         arcTargets,
                                         numNodes) {
+
   check_graph_vertices(arcSources, arcTargets, numNodes)
-  .Call(
-    `_rlemon_FindBiEdgeConnectedCutEdgesRunner`, arcSources, arcTargets,
-    numNodes
-  )
+
+  FindBiEdgeConnectedCutEdgesRunner(arcSources, arcTargets, numNodes)
 }
 
-##' Finds the bi-node-connected components of an undirected graph.
-##' See 'https://lemon.cs.elte.hu/pub/doc/1.3.1/a00616.html#ga9d70526ab54e10b4b6fe3762af8675dd'
-##' for more information.
+##' The bi-node-connected components are the classes of an equivalence relation
+##' on the edges of a undirected graph. Two edges are in the same class if they
+##' are on same circle.
 ##'
-##' @title FindBiNodeConnectedComponents
+##' See \url{https://lemon.cs.elte.hu/pub/doc/1.3.1/a00616.html#ga9d70526ab54e10b4b6fe3762af8675dd}
+##' for more information.
+##' @title Find Bi-Node-Connected Components
 ##' @param arcSources Vector corresponding to the source nodes of a graph's
 ##'   edges
 ##' @param arcTargets Vector corresponding to the destination nodes of a graph's
 ##'   edges
 ##' @param numNodes The number of nodes in the graph
-##' @return A list containing the arc id of each cut arc.
+##' @return A vector containing the arc id of each bi-node-connected component
 ##' @export
 FindBiNodeConnectedComponents <- function(arcSources,
                                           arcTargets,
                                           numNodes) {
+
   check_graph_vertices(arcSources, arcTargets, numNodes)
-  .Call(
-    `_rlemon_FindBiNodeConnectedComponentsRunner`, arcSources, arcTargets,
-    numNodes
-  )
+
+  FindBiNodeConnectedComponentsRunner(arcSources, arcTargets, numNodes)
 }
 
-##' Finds the bi-node-connected cut nodes in an undirected graph.
-##' See 'https://lemon.cs.elte.hu/pub/doc/1.3.1/a00616.html#ga31461f33a748327ea3ef2a3199ffb6c7'
-##' for more information.
+##' The bi-node-connected components are the classes of an equivalence relation
+##' on the edges of a undirected graph. Two edges are in the same class if they
+##' are on same circle.
 ##'
-##' @title FindBiNodeConnectedCutNodes
+##' See \url{https://lemon.cs.elte.hu/pub/doc/1.3.1/a00616.html#ga31461f33a748327ea3ef2a3199ffb6c7}
+##' for more information.
+##' @title Find Bi-Node-Connected Cut Nodes
 ##' @param arcSources Vector corresponding to the source nodes of a graph's
 ##'   edges
 ##' @param arcTargets Vector corresponding to the destination nodes of a graph's
 ##'   edges
 ##' @param numNodes The number of nodes in the graph
-##' @return A list containing the cut nodes.
+##' @return A vector containing the cut nodes.
 ##' @export
 FindBiNodeConnectedCutNodes <- function(arcSources,
                                         arcTargets,
                                         numNodes) {
+
   check_graph_vertices(arcSources, arcTargets, numNodes)
-  .Call(
-    `_rlemon_FindBiNodeConnectedCutNodesRunner`, arcSources, arcTargets,
-    numNodes
-  )
+
+  FindBiNodeConnectedCutNodesRunner(arcSources, arcTargets, numNodes)
 }
 
-##' Finds the connected components in an undirected graph.
-##' See 'https://lemon.cs.elte.hu/pub/doc/1.3.1/a00616.html#gaa467a3e0a8c2e9e762650fd01fadff89'
-##' for more information.
+##' The connected components are the classes of an equivalence relation on the
+##' nodes of an undirected graph. Two nodes are in the same class if they are
+##' connected with a path.
 ##'
-##' @title FindConnectedComponents
+##' See \url{https://lemon.cs.elte.hu/pub/doc/1.3.1/a00616.html#gaa467a3e0a8c2e9e762650fd01fadff89}
+##' for more information.
+##' @title Find Connected Components
 ##' @param arcSources Vector corresponding to the source nodes of a graph's
 ##'   edges
 ##' @param arcTargets Vector corresponding to the destination nodes of a graph's
 ##'   edges
 ##' @param numNodes The number of nodes in the graph
-##' @return A list containing the node id of each connected component.
+##' @return A vector containing the node id of each connected component.
 ##' @export
 FindConnectedComponents <- function(arcSources,
                                     arcTargets,
                                     numNodes) {
+
   check_graph_vertices(arcSources, arcTargets, numNodes)
-  .Call(
-    `_rlemon_FindConnectedComponentsRunner`, arcSources, arcTargets,
-    numNodes
-  )
+
+  FindConnectedComponentsRunner(arcSources, arcTargets, numNodes)
 }
 
-##' Finds the bi-edge-connected components of an undirected graph.
-##' See 'https://lemon.cs.elte.hu/pub/doc/1.3.1/a00616.html#ga76c1fdd1881d21677507100b7e96c983'
-##' for more information.
+##' The bi-edge-connected components are the classes of an equivalence relation
+##' on the nodes of an undirected graph. Two nodes are in the same class if they
+##' are connected with at least two edge-disjoint paths.
 ##'
-##' @title FindBiEdgeConnectedComponents
+##' See \url{https://lemon.cs.elte.hu/pub/doc/1.3.1/a00616.html#ga76c1fdd1881d21677507100b7e96c983}
+##' for more information.
+##' @title Find Bi-Edge-Connected Components
 ##' @param arcSources Vector corresponding to the source nodes of a graph's
 ##'   edges
 ##' @param arcTargets Vector corresponding to the destination nodes of a graph's
 ##'   edges
 ##' @param numNodes The number of nodes in the graph
-##' @return A list containing the node id of each bi-edge-connected component.
+##' @return A vector containing the node id of each bi-edge-connected component.
 ##' @export
 FindBiEdgeConnectedComponents <- function(arcSources,
                                           arcTargets,
                                           numNodes) {
+
   check_graph_vertices(arcSources, arcTargets, numNodes)
-  .Call(
-    `_rlemon_FindBiEdgeConnectedComponentsRunner`, arcSources, arcTargets,
-    numNodes
-  )
+
+  FindBiEdgeConnectedComponentsRunner(arcSources, arcTargets, numNodes)
 }
